/* shutdown.c - reboot, halt, or poweroff the system
 * Time-stamp: <2004-03-09 njk>
 *  
 * (C) 2004 Nicholas J. Kain <njk@aerifal.cx>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 * 
 */

#include <unistd.h>
#include <stdlib.h>
#include <string.h>
#include <sys/reboot.h>

int main(int argc, char** argv) {
	unsigned int halt = 0, do_reboot = 0, poweroff = 0;
	char *p = argv[1];

	while (p && *p) {
		switch (*p) {
			case '-':
				break;
			case 'r':
				do_reboot = 1;
				halt = 0;
				poweroff = 0;
				break;
			case 'h':
				halt = 1;
				do_reboot = 0;
				poweroff = 0;
				break;
			case 'p':
				poweroff = 1;
				do_reboot = 0;
				halt = 0;
				break;
			default:
				exit(EXIT_FAILURE);
				break;
		}
		++p;
	}

	sync();

    if (do_reboot) {
        reboot(RB_AUTOBOOT);
    }

	if (poweroff || halt) {
        reboot(RB_ENABLE_CAD);

        if (poweroff)
            reboot(RB_POWER_OFF);
        reboot(RB_HALT_SYSTEM);
    }

	exit(EXIT_FAILURE);
}

